#!/usr/bin/python
# -*- coding: utf-8 -*-

import affinegap
from haversine import compareLatLong
from cosine import CosineTextSimilarity, CosineSetSimilarity
from categorical import CategoricalComparator
